========
box-plot
========

The :class:`CGATReportPlugins.Plotter.BoxPlot` displays
:term:`numerical arrays` as boxplots.

.. report:: Trackers.SingleColumnDataExample
   :render: box-plot
   :layout: row
   :width: 200

   A box-plot from a tracker returning a single column data.

.. report:: Trackers.ArrayDataExample
   :render: box-plot
   :layout: row
   :width: 200

   A box-plot from a tracker returning multiple columns of data.

Options
-------

:class:`CGATReportPlugins.Plotter.BoxPlot` has no additional
options apart from :ref:`common plot options`. 

